# Змей Горыныч

[Змей Горыныч]((https://ru.wikipedia.org/wiki/%D0%97%D0%BC%D0%B5%D0%B9_%D0%93%D0%BE%D1%80%D1%8B%D0%BD%D1%8B%D1%87)) (сокращенно "змей") - это веб-фреймворк-обертка вокруг Django,
цель которого максимально разгрузить разработчика от рутинной работы.

